<?php

namespace Hyiplab\Controllers\Admin;

use Hyiplab\BackOffice\Request;
use Hyiplab\Controllers\Controller;
use Intervention\Image\ImageManager as Image;

class GeneralSettingController extends Controller
{
    public function index()
    {
        $pageTitle = "General Setting";
        $this->view('admin/setting/index', compact('pageTitle'));
    }

    public function store()
    {
        $request = new Request();
        $request->validate(
            [
                'vl_cur_text' => 'required',
                'vl_cur_sym' => 'required'
            ],
            [
                'vl_cur_text.required' => 'Currency field is required',
                'vl_cur_sym.required' => 'Currency symbol field is required'
            ]
        );

        update_option('vl_cur_text', sanitize_text_field($request->vl_cur_text));
        update_option('vl_cur_sym', sanitize_text_field($request->vl_cur_sym));

        $notify[] = ['success', 'General setting updated successfully'];
        viserBack($notify);
    }

    public function systemConfiguration()
    {
        $pageTitle = "System Configuration";
        return $this->view('admin/setting/configuration', compact('pageTitle'));
    }

    public function systemConfigurationStore()
    {
        $request = viserRequest();

        update_option('vl_email_notification', $request->vl_email_notification ? 1 : 0);
        update_option('vl_sms_notification', $request->vl_sms_notification ? 1 : 0);

        $notify[] = ['success', 'System configuration update successfully'];
        viserBack($notify);
    }

    public function logoIcon()
    {
        $pageTitle = 'Logo & Favicon';
        $this->view('admin/setting/logo_icon', compact('pageTitle'));
    }

    public function logoIconSubmit()
    {
        $request = new Request();
        $request->validate([
            'logo' => 'image|mimes:jpg,jpeg,png',
            'favicon' => 'image|mimes:png',
        ]);

        $path = HYIPLAB_ROOT . 'assets/global/images';
        $image = new Image();

        if ($request->hasFile('logo')) {
            try {
                if (!file_exists($path)) {
                    mkdir($path, 0755, true);
                }
                $image->make($request->logo['tmp_name'])->save($path . '/logo_light.png');
            } catch (\Exception $exp) {
                $notify[] = ['error', 'Couldn\'t upload the logo'];
                viserBack($notify);
            }
        }

        if ($request->hasFile('logo_dark')) {
            try {
                if (!file_exists($path)) {
                    mkdir($path, 0755, true);
                }
                $image->make($request->logo_dark['tmp_name'])->save($path . '/logo.png');
            } catch (\Exception $exp) {
                $notify[] = ['error', 'Couldn\'t upload the dark logo'];
                viserBack($notify);
            }
        }

        if ($request->hasFile('favicon')) {
            try {
                if (!file_exists($path)) {
                    mkdir($path, 0755, true);
                }
                $size = explode('x', vlGetFileSize('favicon'));
                $image->make($request->favicon['tmp_name'])->resize($size[0], $size[1])->save($path . '/favicon.png');
            } catch (\Exception $exp) {
                $notify[] = ['error', 'Couldn\'t upload the favicon'];
                viserBack($notify);
            }
        }

        $notify[] = ['success', 'Logo & favicon updated successfully'];
        viserBack($notify);
    }
}
