<?php

namespace Hyiplab\Controllers\User;

use Hyiplab\BackOffice\Request;
use Hyiplab\Controllers\Controller;
use Hyiplab\Lib\HyipLab;
use Hyiplab\Models\Plan;

class PlanController extends Controller
{
    public function index()
    {
        $this->pageTitle = __("Plans", HYIPLAB_PLUGIN_NAME);
        $plans           = Plan::where('status', 1)->orderBy('id', 'DESC')->get();
        $this->view('user/plan', compact('plans'));
    }

    public function invest()
    {
        global $user_ID;
        $request = new Request();
        $request->validate([
            'amount'      => 'required|numeric',
            'plan_id'     => 'required|integer',
            'wallet_type' => 'required'
        ]);
        $user = get_userdata($user_ID);
        $plan = Plan::where('id', $request->plan_id)->where('status', 1)->firstOrFail();
        
        $amount = floatval($request->amount);

        if ($plan->fixed_amount > 0) {
            if ($amount != $plan->fixed_amount) {
                $notify[] = ['error', 'Please check the investment limit'];
                setNotify($notify);
                viserRedirect(vlRoute('user.plan.index'));
            }
        } else {
            if ($amount < $plan->minimum || $amount > $plan->maximum) {
                $notify[] = ['error', 'Please check the investment limit'];
                setNotify($notify);
                viserRedirect(vlRoute('user.plan.index'));
            }
        }

        $wallet = sanitize_text_field($request->wallet_type);
        if ($amount > hyiplabBalance($user_ID, $wallet)) {
            $notify[] = ['error', 'Your balance is not sufficient'];
            setNotify($notify);
            viserRedirect(vlRoute('user.plan.index'));
        }

        $hyip = new HyipLab($user, $plan);
        $hyip->invest($amount, $wallet);
        $notify[] = ['success', 'Invested to plan successfully'];
        setNotify($notify);
        viserRedirect(vlRoute('user.invest.index'));
    }
}
