<?php

use Hyiplab\BackOffice\Router\Router;
use Hyiplab\Controllers\ActivationController;
use Hyiplab\Controllers\Gateway\Authorize\PaymentProcess;
use Hyiplab\Controllers\Gateway\Blockchain\PaymentProcess as BlockchainPaymentProcess;
use Hyiplab\Controllers\Gateway\Cashmaal\PaymentProcess as CashmaalPaymentProcess;
use Hyiplab\Controllers\Gateway\CoinbaseCommerce\PaymentProcess as CoinbaseCommercePaymentProcess;
use Hyiplab\Controllers\Gateway\Coingate\PaymentProcess as CoingatePaymentProcess;
use Hyiplab\Controllers\Gateway\Coinpayments\PaymentProcess as CoinpaymentsPaymentProcess;
use Hyiplab\Controllers\Gateway\CoinpaymentsFiat\PaymentProcess as CoinpaymentsFiatPaymentProcess;
use Hyiplab\Controllers\Gateway\Flutterwave\PaymentProcess as FlutterwavePaymentProcess;
use Hyiplab\Controllers\Gateway\Instamojo\PaymentProcess as InstamojoPaymentProcess;
use Hyiplab\Controllers\Gateway\MercadoPago\PaymentProcess as MercadoPagoPaymentProcess;
use Hyiplab\Controllers\Gateway\Mollie\PaymentProcess as MolliePaymentProcess;
use Hyiplab\Controllers\Gateway\NMI\PaymentProcess as NMIPaymentProcess;
use Hyiplab\Controllers\Gateway\Payeer\PaymentProcess as PayeerPaymentProcess;
use Hyiplab\Controllers\Gateway\Paypal\PaymentProcess as PaypalPaymentProcess;
use Hyiplab\Controllers\Gateway\PaypalSdk\PaymentProcess as PaypalSdkPaymentProcess;
use Hyiplab\Controllers\Gateway\Paystack\PaymentProcess as PaystackPaymentProcess;
use Hyiplab\Controllers\Gateway\Paytm\PaymentProcess as PaytmPaymentProcess;
use Hyiplab\Controllers\Gateway\PerfectMoney\PaymentProcess as PerfectMoneyPaymentProcess;
use Hyiplab\Controllers\Gateway\Razorpay\PaymentProcess as RazorpayPaymentProcess;
use Hyiplab\Controllers\Gateway\Skrill\PaymentProcess as SkrillPaymentProcess;
use Hyiplab\Controllers\Gateway\Stripe\PaymentProcess as StripePaymentProcess;
use Hyiplab\Controllers\Gateway\StripeJs\PaymentProcess as StripeJsPaymentProcess;
use Hyiplab\Controllers\Gateway\StripeV3\PaymentProcess as StripeV3PaymentProcess;
use Hyiplab\Controllers\Gateway\VoguePay\PaymentProcess as VoguePayPaymentProcess;
use Hyiplab\Controllers\User\Auth\ForgotPasswordController;
use Hyiplab\Controllers\User\Auth\LoginController;
use Hyiplab\Controllers\User\Auth\RegisterController;
use Hyiplab\Controllers\User\DashboardController;
use Hyiplab\Controllers\User\DepositController;
use Hyiplab\Controllers\User\InvestController;
use Hyiplab\Controllers\User\PlanController;
use Hyiplab\Controllers\User\ProfileController;
use Hyiplab\Controllers\User\ReferralController;
use Hyiplab\Controllers\User\TicketController;
use Hyiplab\Controllers\User\TransactionController;
use Hyiplab\Controllers\User\WithdrawController;

$router = new Router;

$router->router([
    'user.login'=>[
        'method'     => 'get',
        'uri'        => 'login',
        'middleware' => ['authorized','checkPlugin'],
        'action'     => [LoginController::class,'login'],
    ]
]);

$router->router([
    'user.logout'=>[
        'method'     => 'get',
        'uri'        => 'logout',
        'middleware' => ['auth','checkPlugin'],
        'action'     => [LoginController::class,'logout'],
    ]
]);

$router->router([
    'user.forget.password'=>[
        'method'     => 'any',
        'uri'        => 'forgot',
        'middleware' => ['authorized','checkPlugin'],
        'action'     => [ForgotPasswordController::class,'forgot'],
    ]
]);

$router->router([
    'user.register'=>[
        'method'     => 'any',
        'uri'        => 'register',
        'middleware' => ['authorized','allow_registration','checkPlugin'],
        'action'     => [RegisterController::class,'showRegisterForm'],
    ]
]);

$router->router([
    'user.home'=>[
        'method'     => 'get',
        'uri'        => 'user-dashboard',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [DashboardController::class, 'index'],
    ]
]);

$router->router([
    'user.ban'=>[
        'method'     => 'get',
        'uri'        => 'user-ban',
        'middleware' => ['auth','checkPlugin','checkPlugin'],
        'action'     => [DashboardController::class, 'userBan'],
    ]
]);

//deposit
$router->router([
    'user.deposit.index'=>[
        'method'     => 'get',
        'uri'        => 'user-dashboard/deposit',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [DepositController::class, 'index'],
    ]
]);

$router->router([
    'user.deposit.insert'=>[
        'method'     => 'post',
        'uri'        => 'user-dashboard/deposit-insert',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [DepositController::class, 'insert'],
    ]
]);

$router->router([
    'user.deposit.manual'=>[
        'method'     => 'get',
        'uri'        => 'user-dashboard/deposit-manual',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [DepositController::class, 'manual'],
    ]
]);

$router->router([
    'user.deposit.manual.update'=>[
        'method'     => 'post',
        'uri'        => 'user-dashboard/deposit-manual-update',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [DepositController::class, 'manualUpdate'],
    ]
]);

$router->router([
    'user.deposit.confirm'=>[
        'method'     => 'get',
        'uri'        => 'user-dashboard/deposit-confirm',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [DepositController::class, 'confirm'],
    ]
]);

$router->router([
    'user.deposit.history'=>[
        'method'     => 'get',
        'uri'        => 'user-dashboard/deposit-history',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [DepositController::class, 'history'],
    ]
]);

// ======================================================= IPN ==========================================================
$router->router([
    'ipn.stripe'=>[
        'method'     => 'post',
        'uri'        => 'ipn/stripe',
        'middleware' => ['checkPlugin'],
        'action'     => [StripePaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.authorize'=>[
        'method'     => 'post',
        'uri'        => 'ipn/authorize',
        'middleware' => ['checkPlugin'],
        'action'     => [PaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.blockchain'=>[
        'method'     => 'any',
        'uri'        => 'ipn/blockchain',
        'middleware' => ['checkPlugin'],
        'action'     => [BlockchainPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.cashmaal'=>[
        'method'     => 'any',
        'uri'        => 'ipn/cashmaal',
        'middleware' => ['checkPlugin'],
        'action'     => [CashmaalPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.coinbasecommerce'=>[
        'method'     => 'any',
        'uri'        => 'ipn/coinbasecommerce',
        'middleware' => ['checkPlugin'],
        'action'     => [CoinbaseCommercePaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.coingate'=>[
        'method'     => 'any',
        'uri'        => 'ipn/coingate',
        'middleware' => ['checkPlugin'],
        'action'     => [CoingatePaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.coinpayments'=>[
        'method'     => 'any',
        'uri'        => 'ipn/coinpayments',
        'middleware' => ['checkPlugin'],
        'action'     => [CoinpaymentsPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.coinpaymentsfiat'=>[
        'method'     => 'any',
        'uri'        => 'ipn/coinpaymentsfiat',
        'middleware' => ['checkPlugin'],
        'action'     => [CoinpaymentsFiatPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.flutterwave'=>[
        'method'     => 'any',
        'uri'        => 'ipn/flutterwave',
        'middleware' => ['checkPlugin'],
        'action'     => [FlutterwavePaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.instamojo'=>[
        'method'     => 'any',
        'uri'        => 'ipn/instamojo',
        'middleware' => ['checkPlugin'],
        'action'     => [InstamojoPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.mercadopago'=>[
        'method'     => 'any',
        'uri'        => 'ipn/mercadopago',
        'middleware' => ['checkPlugin'],
        'action'     => [MercadoPagoPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.mollie'=>[
        'method'     => 'any',
        'uri'        => 'ipn/mollie',
        'middleware' => ['checkPlugin'],
        'action'     => [MolliePaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.nmi'=>[
        'method'     => 'any',
        'uri'        => 'ipn/nmi',
        'middleware' => ['checkPlugin'],
        'action'     => [NMIPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.payeer'=>[
        'method'     => 'any',
        'uri'        => 'ipn/payeer',
        'middleware' => ['checkPlugin'],
        'action'     => [PayeerPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.paypal'=>[
        'method'     => 'any',
        'uri'        => 'ipn/paypal',
        'middleware' => ['checkPlugin'],
        'action'     => [PaypalPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.paypalsdk'=>[
        'method'     => 'any',
        'uri'        => 'ipn/paypalsdk',
        'middleware' => ['checkPlugin'],
        'action'     => [PaypalSdkPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.paystack'=>[
        'method'     => 'any',
        'uri'        => 'ipn/paystack',
        'middleware' => ['checkPlugin'],
        'action'     => [PaystackPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.paytm'=>[
        'method'     => 'any',
        'uri'        => 'ipn/paytm',
        'middleware' => ['checkPlugin'],
        'action'     => [PaytmPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.perfectmoney'=>[
        'method'     => 'any',
        'uri'        => 'ipn/perfectmoney',
        'middleware' => ['checkPlugin'],
        'action'     => [PerfectMoneyPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.razorpay'=>[
        'method'     => 'any',
        'uri'        => 'ipn/razorpay',
        'middleware' => ['checkPlugin'],
        'action'     => [RazorpayPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.skrill'=>[
        'method'     => 'any',
        'uri'        => 'ipn/skrill',
        'middleware' => ['checkPlugin'],
        'action'     => [SkrillPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.stripejs'=>[
        'method'     => 'any',
        'uri'        => 'ipn/stripejs',
        'middleware' => ['checkPlugin'],
        'action'     => [StripeJsPaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.stripev3'=>[
        'method'     => 'any',
        'uri'        => 'ipn/stripev3',
        'middleware' => ['checkPlugin'],
        'action'     => [StripeV3PaymentProcess::class, 'ipn']
    ]
]);
$router->router([
    'ipn.voguepay'=>[
        'method'     => 'any',
        'uri'        => 'ipn/voguepay',
        'middleware' => ['checkPlugin'],
        'action'     => [VoguePayPaymentProcess::class, 'ipn']
    ]
]);
// ======================================================= IPN ==========================================================

$router->router([
    'user.withdraw.index'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/withdraw',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [WithdrawController::class, 'index'],
    ]
]);

$router->router([
    'user.withdraw.insert'=> [
        'method'     => 'post',
        'uri'        => 'user-dashboard/withdraw-insert',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [WithdrawController::class, 'insert'],
    ]
]);

$router->router([
    'user.withdraw.preview'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/withdraw-preview',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [WithdrawController::class, 'preview'],
    ]
]);

$router->router([
    'user.withdraw.submit'=> [
        'method'     => 'post',
        'uri'        => 'user-dashboard/withdraw-submit',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [WithdrawController::class, 'submit'],
    ]
]);

$router->router([
    'user.withdraw.history'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/withdraw-history',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [WithdrawController::class, 'history'],
    ]
]);

$router->router([
    'user.transaction.index'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/transactions',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [TransactionController::class, 'index'],
    ]
]);

$router->router([
    'user.change.password'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/change-password',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [ProfileController::class, 'changePassword'],
    ]
]);

$router->router([
    'user.change.password.update'=> [
        'method'     => 'post',
        'uri'        => 'user-dashboard/change-password-update',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [ProfileController::class, 'changePasswordUpdate'],
    ]
]);

$router->router([
    'user.profile.setting'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/profile-setting',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [ProfileController::class, 'profileSetting'],
    ]
]);

$router->router([
    'user.profile.setting.update'=> [
        'method'     => 'post',
        'uri'        => 'user-dashboard/profile-setting-update',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [ProfileController::class, 'profileSettingUpdate'],
    ]
]);

$router->router([
    'user.ticket.index'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/tickets',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [TicketController::class, 'myTicket'],
    ]
]);

$router->router([
    'user.ticket.create'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/ticket-create',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [TicketController::class, 'createTicket'],
    ]
]);

$router->router([
    'user.ticket.store'=> [
        'method'     => 'post',
        'uri'        => 'user-dashboard/ticket-store',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [TicketController::class, 'storeTicket'],
    ]
]);

$router->router([
    'user.ticket.view'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/ticket-view',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [TicketController::class, 'viewTicket'],
    ]
]);

$router->router([
    'user.ticket.close'=> [
        'method'     => 'post',
        'uri'        => 'user-dashboard/ticket-close',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [TicketController::class, 'closeTicket'],
    ]
]);

$router->router([
    'user.ticket.reply'=> [
        'method'     => 'post',
        'uri'        => 'user-dashboard/ticket-reply',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [TicketController::class, 'replyTicket'],
    ]
]);

$router->router([
    'user.ticket.download'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/ticket-download',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [TicketController::class, 'downloadTicket'],
    ]
]);

$router->router([
    'user.invest.index'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/invest',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [InvestController::class, 'index'],
    ]
]);
$router->router([
    'user.invest.log'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/invest-log',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [InvestController::class, 'log'],
    ]
]);
$router->router([
    'user.plan.index'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/plan',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [PlanController::class, 'index'],
    ]
]);
$router->router([
    'user.plan.invest'=> [
        'method'     => 'post',
        'uri'        => 'user-dashboard/plan-invest',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [PlanController::class, 'invest'],
    ]
]);
$router->router([
    'user.referral.index'=> [
        'method'     => 'get',
        'uri'        => 'user-dashboard/referrals',
        'middleware' => ['auth', 'checkStatus', 'checkPlugin'],
        'action'     => [ReferralController::class, 'index'],
    ]
]);



// activation routes
$router->router([
    'plugin.activation'=> [
        'method'     => 'get',
        'uri'        => HYIPLAB_PLUGIN_NAME.'-activation',
        'action'     => [ActivationController::class, 'activate'],
    ]
]);